import { Injectable } from '@angular/core';
import { Spell } from 'src/interfaces/spell';
import { Subject } from 'rxjs';

@Injectable({
  providedIn: 'root',
})
export class SpellsService {
  // Functions

  private _closeSubject = new Subject<number>();

  public closeSubject$ = this._closeSubject.asObservable();

  constructor() {}

  public closeAllOthers(level: number): void {
    this._closeSubject.next(level);
  }

  // Custom Spells

  public customSpells: Spell[] = [];

  /**
   * Returns an array of available spells for the given level and character class.
   * The results come from the official apells array and the custom spells array.
   * @param level The level of the spell.
   * @param characterClass The character class of the spell.
   * @returns An array of available spells.
   */
  public getAvailableSpells(level: number, characterClass: string): Spell[] {
    let result = this.spells
      .filter((spell) => spell.level === level)
      .filter((spell) => spell.classes.includes(characterClass));
    result.push(...this.customSpells.filter((spell) => spell.level === level));
    console.log(result);

    return result;
  }

  /**
   * Deletets a single spell from the custom spells array and the full spells array.
   * @param spellToDelete The spell to be deleted from the custom spells.
   */
  public deleteCustomSpell(spellToDelete: Spell): void {
    const customIndex = this.customSpells.findIndex(
      (spell) => spell.id === spellToDelete.id
    );
    if (customIndex > -1) {
      this.customSpells.splice(customIndex, 1);
    }
    const fullIndex = this.spells.findIndex(
      (spell) => spell.id === spellToDelete.id
    );
    if (fullIndex > -1) {
      this.spells.splice(fullIndex, 1);
    }
  }

  //

  private spells: Spell[] = [
    // Level 0
    {
      id: 0,
      isCustom: false,
      german: 'Göttliche Führung',
      english: 'guidance',
      classes: ['Test', 'Cleric', 'Druid'],
      level: 0,
      cost: 'action',
      duration: 10,
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        Du berührst eine bereitwillige Kreatur. Einmal vor dem Ende des Zaubers kann das Ziel mit einem W4 würfeln und das Ergebnis zu einem Attributswurf seiner Wahl addieren. Es kann mit dem W4 vor oder nach dem Attributswurf würfeln. Dann endet der Zauber.
      `,
      description_en: `
        You touch one willing creature. Once before the spell ends, the target can roll a d4 and add the number rolled to one ability check of its choice. It can roll the die before or after making the ability check. The spell then ends.
      `,
      school: 'Divination',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1,
      isCustom: false,
      german: 'Totenläuten',
      english: 'tollTheDead',
      classes: ['Test', 'Cleric', 'Warlock', 'Wizard'],
      level: 0,
      cost: 'action',
      duration: 0,
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'wisdom',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd8', damageType: 'necrotic' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du zeigen auf eine Kreatur, die Sie in Reichweite sehen können, und der Klang einer traurigen Glocke erfüllt für einen Moment die Luft um sie herum. Dem Ziel muss ein Weisheitswurf gelingen oder es erleidet 1W8 nekrotischen Schaden. Wenn dem Ziel einer seiner Trefferpunkte fehlt, erleidet es stattdessen 1W12 nekrotischen Schaden.

        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um einen Würfel, wenn du 5 erreichstth Stufe (2W8 oder 2W12), 11th Stufe (3W8 oder 3W12) und 17th Stufe (4W8 oder 4W12)</p>
      `,
      description_en: `
        <p>You point at one creature you can see within range, and the sound of a dolorous bell fills the air around it for a moment. The target must succeed on a Wisdom saving throw or take 1d8 necrotic damage. If the target is missing any of its hit points, it instead takes 1d12 necrotic damage.<p>

        <p> <b>At Higher Levels:</b> The spell’s damage increases by one die when you reach 5th level (2d8 or 2d12), 11th level (3d8 or 3d12), and 17th level (4d8 or 4d12).<p>
      `,
      school: 'Necromancy',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 2,
      isCustom: false,
      german: 'Thaumaturgie',
      english: 'thaumaturgy',
      classes: ['Test', 'Cleric'],
      level: 0,
      cost: 'action',
      duration: 10,
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du manifestierst ein kleines Wunder, ein Zeichen übernatürlicher Macht, in Reichweite. Du kannst einen der folgenden magischen Effekte in Reichweite erschaffen:</p>
        <ul>
          <li>Deine Stimme dröhnt für 1 Minute dreimal so laut, wie normal.</li>
          <li>Du lässt Flammen flackern, heller oder dunkler werden oder die Farbe wechseln. All dies hält 1 Minute an.</li>
          <li>Du erzeugst für 1 Minute harmlose Erschütterungen im Boden.</li>
          <li>Du erschaffst ein kurzes Geräusch, das von einem Punkt deiner Wahl in Reichweite ertönt, wie ein Grollen von Donner, den Ruf eines Raben oder ein unheilvolles Flüstern.</li>
          <li>Du lässt eine nicht verriegelte Tür oder ein Fenster auffliegen oder zuschlagen.</li>
          <li>Du änderst für 1 Minute das Aussehen deiner Augen.</li>
        </ul>
        <p>Wenn du diesen Zauber mehrmals wirkst, kannst du bis zu drei der nicht sofortigen Effekte gleichzeitig aktiviert haben und du kannst solche Effekte als Aktion aufheben.</p>
      `,
      description_en: `
        <p>You manifest a minor wonder, a sign of supernatural power, within range. You create one of the following magical effects within range.</p>
        <ul>
          <li>Your voice booms up to three times as loud as normal for 1 minute.</li>
          <li>You cause flames to flicker, brighten, dim, or change color for 1 minute.</li>
          <li>> You cause harmless tremors in the ground for 1 minute.</li>
          <li>You create an instantaneous sound that originates from a point of your choice within range, such as a rumble of thunder, the cry of a raven, or ominous whispers.</li>
          <li>You instantaneously cause an unlocked door or window to fly open or slam shut.</li>
          <li>You alter the appearance of your eyes for 1 minute.</li>
        <p>If you cast this spell multiple times, you can have up to three of its 1-minute effects active at a time, and you can dismiss such an effect as an action.</p>
      `,
      school: 'Transmutation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 3,
      german: 'Gift versprühen',
      english: 'sprayPoison',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid', 'Artificer', 'Sorcerer', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Constitution',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd12', damageType: 'poison' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `<p>Du streckst deine Hand in Richtung einer Kreatur in Reichweite, die du sehen kannst, und erzeugst eine Wolke aus ekelhaftem Gas aus deiner Handfläche. Die Kreatur muss einen Konstitutionsrettungswurf schaffen, sonst erleidet sie 1W12 Giftschaden.</p>`,
      description_en: `
        <p>You extend your hand toward a creature you can see within range and project a puff of noxious gas from your palm. The creature must succeed on a Constitution saving throw or take 1d12 poison damage.</p>
      `,
      school: 'Conjuration',
      isRanged: true,
      range: 10,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 4,
      german: 'Ausbessern',
      english: 'mending',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Cleric', 'Druid', 'Wizard', 'Sorcerer'],
      timeToCast: 10,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Dieser Zauber repariert eine Bruchstelle oder einen Riss in einem Gegenstand, den du berührst, wie ein zerbrochenes Kettenglied, die beiden Hälften eines zerbrochenen Schlüssels, einen zerrissenen Umhang oder einen lecken Weinschlauch. Solange der Riss oder die Bruchstelle in keiner Dimension größer als 1 Fuß ist, kannst du sie flicken, sodass keine Spur des vorherigen Schadens übrigbleibt.</p>
        <p>Der Zauber kann einen magischen Gegenstand oder ein Konstrukt auf physische Weise reparieren, der Zauber kann einem solchen Gegenstand aber nicht seine Magie wiedergeben.</p>`,
      description_en: `
        <p>This spell repairs a single break or tear in an object you touch, such as broken chain link, two halves of a broken key, a torn clack, or a leaking wineskin. As long as the break or tear is no larger than 1 foot in any dimension, you mend it, leaving no trace of the former damage.</p>
        <p>This spell can physically repair a magic item or construct, but the spell can't restore magic to such an object.</p>
      `,
      school: 'Transmutation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 5,
      german: 'Befall',
      english: 'infestation',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid', 'Sorcerer', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Constitution',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd6', damageType: 'poison' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du lässt eine Wolke aus Parasiten auf ein Ziel in maximal 30 Fuß Distanz localStorage. Das Ziel muss einen Konstitutionsrettungswurf bestehen, oder 1W6 Giftschaden erleiden und 5 Fuß in eine zufällige Richtung laufen. Ein W4 gibt die Richtung vor:</p>
        <ul>
          <li>1: Norden</li>
          <li>2: Süden</li>
          <li>3: Westen</li>
          <li>4: Osten</li>
        </ul>
        <p>Der Zauber löst keine Gelegenheitsangriffe aus.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um 1W6, wenn du die 5. Stufe (2W6), die 11. Stufe (3W6) und die 17. Stufe (4W6) erreichst.</p>
      `,
      description_en: `
        <p>You cause a cloud of mites, fleas, and other parasites to appear momentarily on one creature you can see within range. The target must succeed on a Constitution saving throw, or it takes 1d6 poison damage and moves 5 feet in a random direction if it can move and its speed is at least 5 feet. Roll a d4 for the direction:
        <ul>
          <li>1: north</li>
          <li>2: south</li>
          <li>3: east</li>
          <li>4: west</li>
          </ul>
        <p>This movement doesn’t provoke opportunity attacks, and if the direction rolled is blocked, the target doesn’t move.</p>
        <p>The spell’s damage increases by 1d6 when you reach 5th level (2d6), 11th level (3d6), and 17th level (4d6).</p>
      `,
      school: 'Conjuration',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
    },
    {
      id: 6,
      german: 'Blitzköder',
      english: 'lightningLure',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Sorcerer', 'Wizard', 'Warlock'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Strength',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd8', damageType: 'lightning' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du wirft eine Blitzfalle auf eine Kreatur in 15 Fuß Distanz. Das Ziel muss einen Stärkerettungswurf bestehen, oder 1W8 Blitzschaden erleiden und 10 Fuß in deine Richtung gezogen werden.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um 1W8, wenn du die 5. Stufe (2W8), die 11. Stufe (3W8) und die 17. Stufe (4W8) erreichst.</p>
      `,
      description_en: `
        <p>You create a lash of lightning energy that strikes at one creature of your choice that you can see within range. The target must succeed on a Strength saving throw or be pulled up to 10 feet in a straight line toward you and then take 1d8 lightning damage if it is within 5 feet of you.</p>
        <p><b>At Higher Levels:</b> The spell’s damage increases by 1d8 when you reach 5th level (2d8), 11th level (3d8), and 17th level (4d8).</p>

      `,
      school: 'Evocation',
      isRanged: true,
      range: 15,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
    },
    {
      id: 7,
      german: 'Botschaft',
      english: 'message',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Wizard', 'Sorcerer'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
      <p>Du deutest mit dem Finger auf eine Kreatur in Reichweite und flüsterst eine Botschaft. Das Ziel (und nur das Ziel) hört die Botschaft und kann in einem Flüstern antworten, das nur du hören kannst.</p>
      <p>Du kannst diesen Zauber durch feste Gegenstände hindurch wirken, wenn du das Ziel kennst und weißt, dass es jenseits der Barriere liegt. "Magische Stille", 1 Fuß Stein, 15 Fuß Holz, eine dünne Schicht Blei oder gewöhnliches Metall blockieren den Zauber. Der Zauber muss nicht einer geraden Linie folgen und kann frei um Ecken oder durch Öffnungen reisen.</p>`,
      description_en: `
      <p>You point your finger toward a creature within range and whisper a message. The target (and only the target) hears the message and can reply in a whisper that only you can hear.</p>
      <p>You can cast this spell through solid objects if you are familiar with the target and know it is beyond the barrier. Magical silence, 1 foot of stone, 1 inch of common metal, a thin sheet of lead, or 3 feet of wood blocks the spell. The spell doesn’t have to follow a straight line and can travel freely around corners or through openings.</p>
      `,
      school: 'Transmutation',
      isRanged: true,
      range: 120,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 8,
      german: 'Donnerschlag',
      english: 'thunderclap',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Druid', 'Sorcerer', 'Warlock', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Constitution',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd6', damageType: 'thunder' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du erzeugst einen Knall, der bis zu 100 Fuß weit zu hören ist. Jede Kreatur in Reichweite, außer dir, muss einen Konstitutionsrettungswurf schaffen oder 1W6 Donnerschaden erleiden.</p>
        <p>Der Schaden des Zaubers erhöht sich um 1W6, wenn du die 5. Stufe (2W6), die 11. Stufe (3W6) und die 17. Stufe (4W6) erreichst.</p>
        `,
      description_en: `
        <p>You create a burst of thunderous sound that can be heard up to 100 feet away. Each creature within range, other than you, must succeed on a Constitution saving throw or take 1d6 thunder damage.</p>
        <p>The spell’s damage increases by 1d6 when you reach 5th level (2d6), 11th level (3d6), and 17th level (4d6).</p>
      `,
      school: 'Evocation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: true,
      areaOfEffectType: 'circle',
      radius: 5,
    },
    {
      id: 9,
      german: 'Dornenpeitsche',
      english: 'thornWhip',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid', 'Artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd6', damageType: 'piercing' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du erschaffst eine lange, dornige Peitsche aus Efeu oder einem anderen Pflanzenmaterial, die du auf eine Kreatur in Reichweite richtest. Dein Angriffswurf mit dem Zauberangriffswurf bestimmt, ob der Zauber trifft oder nicht. Bei einem Treffer erleidet das Ziel 1W6 Piercingschaden und du ziehst das Ziel 10 Fuß in deine Richtung. Wenn das Ziel dadurch in deine Reichweite kommt, kannst du es mit einem Angriff mit einer Nahkampfwaffe deiner Wahl angreifen.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um 1W6, wenn du die 5. Stufe (2W6), die 11. Stufe (3W6) und die 17. Stufe (4W6) erreichst.</p>`,
      description_en: `
        <p>You create a long, vine-like whip covered in thorns that lashes out at your command toward a creature in range. Make a melee spell attack against the target. If the attack hits, the creature takes 1d6 piercing damage, and if the creature is Large or smaller, you pull the creature up to 10 feet closer to you.</p>
        <p>This spell’s damage increases by 1d6 when you reach 5th level (2d6), 11th level (3d6), and 17th level (4d6).</p>
      `,
      school: 'Transmutation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 10,
      german: 'Druidenkunst',
      english: 'druidcraft',
      level: 0,
      isCustom: false,

      classes: ['Test', 'Druid'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du flüsterst den Geistern der Natur zu und erschaffst innerhalb der Reichweite einen der folgenden Effekte:</p>
        <ul>
          <li>Du erschaffst einen kleinen, harmlosen sensorischen Effekt der vorhersagt, wie das Wetter an deinem Aufenthaltsort für die nächsten 24 Stunden sein wird. Der Effekt könnte sich als goldene Kugel für einen klaren Himmel, als Wolke für Regen, als fallende Schneeflocken für Schnee – und so weiter – manifestieren. Dieser Effekt hält eine Runde lang an.</li>
          <li>Du sorgst dafür, dass augenblicklich eine Blume erblüht, eine Samenkapsel sich öffnet oder eine Blattknospe aufblüht.</li>
          <li>Du erschaffst einen augenblicklichen, harmlosen sensorischen Effekt, wie fallende Blätter, einen Windhauch, die Geräusche eines kleinen Tieres oder den leichten Geruch eines Stinktiers. Der Effekt muss in einem Würfel mit 5 Fuß Kantenlänge passen.</li>
          <li>Du kannst augenblicklich eine Kerze, eine Fackel oder ein kleines Lagerfeuer entzünden oder löschen.</li>
        </ul>
          `,
      description_en: `
        <p>Whispering to the spirits of nature, you create one of the following effects within range:</p>
        <ul>
          <li>You create a tiny, harmless sensory effect that predicts what the weather will be at your location for the next 24 hours. The effect might manifest as a golden orb for clear skies, a cloud for rain, falling snowflakes for snow, and so on. This effect persists for 1 round.</li>
          <li>You instantly make a flower blossom, a seed pod open, or a leaf bud bloom.</li>
          <li>You create an instantaneous, harmless sensory effect, such as falling leaves, a puff of wind, the sound of a small animal, or the faint odor of skunk. The effect must fit in a 5-foot cube.</li>
          <li>You instantly light or snuff out a candle, a torch, or a small campfire.</li>
        </ul>
      `,
      school: 'Transmutation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 11,
      german: 'Dröhnende Klinge',
      english: 'boomingBlade',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Sorcerer', 'Warlock', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      canRitual: 'false',
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd8', damageType: 'thunder' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
      <p>Du schwingst die Waffe, mit der der Zauber gewirkt wurde, und führst mit ihr einen Nahkampfangriff gegen eine Kreatur im Umkreis von 5 Fuß um dich herum aus. Bei einem Treffer erleidet das Ziel die normalen Effekte des Waffenangriffs und wird dann bis zum Beginn deines nächsten Zuges von dröhnender Energie umhüllt. Wenn sich das Ziel bis dahin freiwillig 5 Fuß oder mehr bewegt, erleidet das Ziel 1W8 Donnerschaden und der Zauber endet.</p>
      <p>Der Schaden des Zaubers erhöht sich um 1W8, wenn du die 5. Stufe (2W8), die 11. Stufe (3W8) und die 17. Stufe (4W8) erreichst.</p>
      `,
      description_en: `
      <p>You brandish the weapon used in the spell’s casting and make a melee attack with it against one creature within 5 feet of you. On a hit, the target suffers the weapon attack’s normal effects and then becomes sheathed in booming energy until the start of your next turn. If the target willingly moves 5 feet or more before then, the target takes 1d8 thunder damage, and the spell ends.</p>
      <p>At 5th level, the melee attack deals an extra 1d8 thunder damage to the target on a hit, and the damage the target takes for moving increases to 2d8. Both damage rolls increase by 1d8 at 11th level (2d8 and 3d8) and again at 17th level (3d8 and 4d8).</p>
      `,
      school: 'Evocation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 11,
      german: 'Einfache Illusion',
      english: 'minorIllusion',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Wizard', 'Warlock', 'Sorcerer'],
      timeToCast: 0,
      cost: 'action',
      duration: 1,
      canRitual: 'false',
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
      <p>Du erschaffst ein Geräusch oder ein Bild eines Gegenstands in Reichweite, das für die Wirkungsdauer anhält. Die Illusion endet auch, wenn du sie als Aktion aufhebst oder diesen Zauber noch einmal wirkst. Wenn du ein Geräusch erschaffst, kann die Lautstärke von einem Flüstern bis zu einem Schrei reichen. Es kann deine Stimme sein, die Stimme eines anderen, das Brüllen eines Löwen, schlagende Trommeln oder ein anderes Geräusch deiner Wahl. Das Geräusch hält für die Wirkungsdauer an, oder du machst einzelne Laute zu verschiedenen Zeiten bis der Zauber endet.</p>
      <p>Wenn du das Bildnis eines Gegenstandes erschaffst - wie das eines Stuhles, schlammiger Fußabdrücke oder einer kleinen Truhe - kann es nicht größer als ein Würfel mit einer Seitenlänge von 1,50m sein. Das Bild kann keine Geräusche, kein Licht, keine Gerüche oder andere sensorische Effekte erzeugen. Körperliche Interaktion mit dem Trugbild offenbart, dass es sich um eine Illusion handelt, weil Dinge es einfach durchdringen können. Eine Kreatur, die ihre Aktion verwendet, um das Bildnis oder das Geräusch zu untersuchen, kann erkennen, dass es sich um eine Illusion handelt, indem sie einen erfolgreichen Wurf auf Intelligenz (Nachforschungen) gegen deinen Zauberrettungswurf-SG ablegt. Wenn die Kreatur die Illusion als das durchschaut, was sie ist, dann verblast sie für die Kreatur.</p>
      `,
      description_en: `
      <p>You create a sound or an image of an object within range that lasts for the duration. The illusion also ends if you dismiss it as an action or cast this spell again.</p>
      <p>If you create a sound, its volume can range from a whisper to a scream. It can be your voice, someone else’s voice, a lion’s roar, a beating of drums, or any other sound you choose. The sound continues unabated throughout the duration, or you can make discrete sounds at different times before the spell ends.</p>
      <p>If you create an image of an object - such as a chair, muddy footprints, or a small chest - it must be no larger than a 5-foot cube. The image can’t create sound, light, smell, or any other sensory effect. Physical interaction with the image reveals it to be an illusion, because things can pass through it. A creature that uses its action to examine the image can determine that it is an illusion with a successful Intelligence (Investigation) check against your spell save DC. If a creature discerns the illusion for what it is, the illusion becomes faint to the creature.</p>
      `,
      school: 'Illusion',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 12,
      german: 'Erde Formen',
      english: 'moldEarth',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid', 'Artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 600,
      canRitual: 'false',
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: true,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du wählst ein Stück Erde oder Stein in Reichweite, das du sehen kannst und das in einen Würfel von 5 Fußn passt. Du kannst es auf eine der folgenden Arten manipulieren:</p>
        <ul>
          <li>Wenn du einen Bereich mit loser Erde anvisierst, kannst du sie augenblicklich ausheben, über den Boden bewegen und bis zu 5 Fuß entfernt ablegen. Diese Bewegung hat nicht genug Kraft, um Schaden zu verursachen.</li>
          <li>Du lässt Formen, Farben oder beides auf der Erde oder den Steinen erscheinen, indem du Wörter schreibst, Bilder kreierst oder Muster formst. Die Veränderungen halten 1 Stunde lang an.</li>
          <li>Befindet sich die Erde oder der Stein, auf den du zielst, auf dem Boden, verwandelst du ihn in schwieriges Terrain. Alternativ kannst du den Boden auch in normales Gelände verwandeln, wenn er bereits schwieriges Gelände ist. Diese Veränderung hält 1 Stunde lang an.</li>
        </ul>
        <p>Wenn du diesen Zauber mehrmals wirkst, kannst du nicht mehr als zwei seiner nicht-augenblicklichen Effekte gleichzeitig aktiv haben, und du kannst einen solchen Effekt als eine Aktion abbrechen.</p>
      `,
      description_en: `
        <p>You choose a portion of dirt or stone that you can see within range and that fits within a 5-foot cube. You manipulate it in one of the following ways:</p>
        <ul>
          <li>If you target an area of loose earth, you can instantaneously excavate it, move it along the ground, and deposit it up to 5 feet away. This movement doesn’t have enough force to cause damage.</li>
          <li>You cause shapes, colors, or both to appear on the dirt or stone, spelling out words, creating images, or shaping patterns. The changes last for 1 hour.</li>
          <li>If the dirt or stone you target is on the ground, you cause it to become difficult terrain. Alternatively, you can cause the ground to become normal terrain if it is already difficult terrain. This change lasts for 1 hour.</li>
        </ul>
        <p>If you cast this spell multiple times, you can have no more than two of its non-instantaneous effects active at a time, and you can dismiss such an effect as an action.</p>
      `,
      school: 'Transmutation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: true,
      areaOfEffectType: 'cube',
      radius: 5,
    },
    {
      id: 13,
      german: 'Erfrierung',
      english: 'frostbite',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid', 'Warlock', 'Artificer', 'Sorcerer', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Constitution',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd6', damageType: 'cold' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du verursachst betäubenden Frost auf einer Kreatur in Reichweite, die du sehen kannst. Das Ziel muss einen Rettungswurf auf Konstitution machen. Bei einem misslungenen Rettungswurf erleidet das Ziel 1W6 Kälteschaden und hat Nachteil beim nächsten Angriffswurf, den es vor dem Ende seines nächsten Zuges macht.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W6 wenn du Stufe 5 (auf 2W6), Stufe 11 (auf 3W6) und Stufe 17 (auf 4W6) erreichst.</p>
      `,
      description_en: `
        <p>You cause numbing frost to form on one creature that you can see within range. The target must make a Constitution saving throw. On a failed save, the target takes 1d6 cold damage, and it has disadvantage on the next weapon attack roll it makes before the end of its next turn.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d6 when you reach 5th level (2d6), 11th level (3d6), and 17th level (4d6).</p>
      `,
      school: 'Evocation',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 14,
      german: 'Feuerpfeil',
      english: 'fireBolt',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Sorcerer', 'Wizard', 'Artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd10', damageType: 'fire' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du schleuderst einen Splitter aus Feuer auf eine Kreatur in Reichweite. Lege einen Fernkampf-Zauberangriff gegen das Ziel ab. Bei einem Treffer erleidet das Ziel 1W10 Feuerschaden. Ein brennbarer Gegenstand, der von diesem Zauber getroffen wird, geht in Flammen auf, wenn er nicht getragen oder in der Hand gehalten wird.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W10 wenn du Stufe 5 (auf 2W10), Stufe 11 (auf 3W10) und Stufe 17 (auf 4W10) erreichst.</p>
      `,
      description_en: `
        <p>You hurl a mote of fire at a creature or object within range. Make a ranged spell attack against the target. On a hit, the target takes 1d10 fire damage. A flammable object hit by this spell ignites if it isn’t being worn or carried.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d10 when you reach 5th level (2d10), 11th level (3d10), and 17th level (4d10).</p>
      `,
      school: 'Evocation',
      isRanged: true,
      range: 120,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 15,
      german: 'Flammen Erzeugen',
      english: 'produceFlames',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid'],
      timeToCast: 0,
      cost: 'action',
      duration: 100,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd8', damageType: 'fire' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Eine flackernde Flamme erscheint in deiner Hand. Die Flamme bleibt für die Wirkungsdauer bestehen und beschädigt weder dich noch deine Ausrüstung. Sie strahlt in einem Radius von 15 Fuß helles Licht und in einem zusätzlichen Radius von 15 Fuß dämmriges Licht ab. Der Zauber endet, wenn du ihn als Aktion aufhebst oder noch einmal wirkst.</p>
        <p>Du kannst mit der Flamme auch angreifen, doch dies beendet den Zauber. Wenn du diesen Zauber wirkst, oder als Aktion in einem späteren Zug, kannst du die Flamme auf eine Kreatur innerhalb von 30 Fuß werfen. Lege einen Fernkampf-Zauberangriff ab. Bei einem Treffer erleidet das Ziel 1W8 Feuerschaden.</p>
        <p>Der Schaden des Zaubers erhöht sich um je 1W8 wenn du Stufe 5 (auf 2W8), Stufe 11 (auf 3W8) und Stufe 17 (auf 4W8) erreichst.</p>
      `,
      description_en: `
        <p>A flickering flame appears in your hand. The flame remains there for the duration and harms neither you nor your equipment. The flame sheds bright light in a 10-foot radius and dim light for an additional 10 feet. The spell ends if you dismiss it as an action or if you cast it again.</p>
        <p>You can also attack with the flame, although doing so ends the spell. When you cast this spell, or as an action on a later turn, you can hurl the flame at a creature within 30 feet of you. Make a ranged spell attack. On a hit, the target takes 1d8 fire damage.</p>
        <p>The spell’s damage increases by 1d8 when you reach 5th level (2d8), 11th level (3d8), and 17th level (4d8).</p>
      `,
      school: 'Conjuration',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 16,
      german: 'Flammen kontrollieren',
      english: 'controlFlames',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid', 'Artificer', 'Sorcerer', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 600,
      canRitual: 'false',
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du wählst ein nicht-magisches Feuer in Reichweite, das du sehen kannst, und das in einem Würfel mit einer Seitenlänge von 5 Fuß passt. Du beeinflusst es auf eine der folgenden Arten:</p>
        <ul>
          <li>Du dehnst die Flamme augenblicklich 5 Fuß in eine Richtung aus, vorausgesetzt, dass Holz oder anderer Brennstoff an der neuen Stelle vorhanden ist.</li>
          <li>Du löschst die Flammen innerhalb des Würfels augenblicklich.</li>
          <li>Du verdoppelst oder halbierst den Bereich des hellen und schwachen Lichts, das die Flamme ausstrahlt, veränderst ihre Farbe oder beides. Die Veränderung hält 1 Stunde lang an.</li>
          <li>Du lässt einfache Formen - wie die vage Form einer Kreatur, eines unbelebten Objekts oder eines Ortes - in den Flammen erscheinen und nach Belieben beleben. Die Formen bleiben 1 Stunde lang bestehen.</li>
        </ul>
        <p>Wenn du diesen Zauber mehrmals wirkst, kannst du bis zu drei seiner nicht-augenblicklichen Effekte gleichzeitig aktiv haben, und du kannst einen solchen Effekt als Aktion abbrechen.</p>
      `,
      description_en: `
        <p>You choose nonmagical flame that you can see within range and that fits within a 5-foot cube. You affect it in one of the following ways:</p>
        <ul>
          <li>You instantaneously expand the flame 5 feet in one direction, provided that wood or other fuel is present in the new location.</li>
          <li>You instantaneously extinguish the flames within the cube.</li>
          <li>You double or halve the area of bright light and dim light cast by the flame, change its color, or both. The change lasts for 1 hour.</li>
          <li>You cause simple shapes - such as the vague form of a creature, an inanimate object, or a location - to appear within the flames and animate as you like. The shapes last for 1 hour.</li>
        </ul>
        <p>If you cast this spell multiple times, you can have up to three of its non-instantaneous effects active at a time, and you can dismiss such an effect as an action.</p>
      `,
      school: 'Transmutation',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: true,
      areaOfEffectType: 'cube',
      radius: 5,
    },
    {
      id: 17,
      german: 'Freundschaft',
      english: 'friends',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Sorcerer', 'Warlock', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 10,
      canRitual: 'false',
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Für die Wirkungsdauer hast du einen Vorteil auf alle Charisma-Würfe, die auf eine Kreatur deiner Wahl gewirkt werden, die dir nicht feindlich gesonnen sind. Wenn der Zauber endet, begreift die Kreatur, dass du Magie verwendet hast, um ihre Stimmung zu beeinflussen und wird feindselig. Eine Kreatur, die zu Gewalt neigt, könnte dich angreifen. Andere Kreaturen könnten sich (nach Entscheidung des Spielleiters) andere Möglichkeiten suchen, um sich zu rächen, abhängig von der Art, wie du mit ihr interagiert hast.</p>
      `,
      description_en: `
        <p>For the duration, you have advantage on all Charisma checks directed at one creature of your choice that isn’t hostile toward you. When the spell ends, the creature realizes that you used magic to influence its mood and becomes hostile toward you. A creature prone to violence might attack you. Another creature might seek retribution in other ways (at the DM’s discretion), depending on the nature of your interaction with it.</p>
      `,
      school: 'Enchantment',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 18,
      german: 'Gedankensplitter',
      english: 'mindSliver',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Sorcerer', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,

      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Intelligence',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd6', damageType: 'psychic' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du treibst einen verstörenden Splitter psychischer Energie in den Geist einer Kreatur, die du in Reichweite sehen kannst. Das Ziel muss einen erfolgreichen Rettungswurf auf Intelligenz durchführen, sonst nimmt es 1W6 psychischen Schaden und muss 1W4 von seinem nächsten Rettungswurf vor Ende deines nächsten Zuges abziehen.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W6 wenn du Stufe 5 (auf 2W6), Stufe 11 (auf 3W6) und Stufe 17 (auf 4W6) erreichst.</p>
      `,
      school: 'Enchantment',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 19,
      german: 'Gehässiger Spott',
      english: 'viciousMockery',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Wisdom',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd4', damageType: 'psychic' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du rufst einer Kreatur in Richweite, die du sehen kannst, eine wahre Flut von Beleidigungen entgegen, in die subtile Verzauberungen gewebt sind. Wenn das Ziel dich hören kann (es braucht dich nicht zu verstehen), muss ihm ein Weisheitsrettungswurf gelingen, um nicht 1W4 psychischen Schaden zu erleiden und beim nächsten Angriffswurf im Nachteil zu sein, den es bis zum Einde seines nächsten Zuges ausführt.</p>
        <p><b>Auf höheren Graden:</b> Der Schaden des Zaubers steigt jeweils um 1W4 bei Erreichen der 5. (2W4), 11. (3W4) und 17. Stufe (4W4).</p>`,
      description_en: `
        <p>You unleash a string of insults laced with subtle enchantments at a creature you can see within range. If the target can hear you (though it need not understand you), it must succeed on a Wisdom saving throw or take 1d4 psychic damage and have disadvantage on the next attack roll it makes before the end of its next turn.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d4 when you reach 5th level (2d4), 11th level (3d4), and 17th level (4d4).</p>
      `,
      school: 'Enchantment',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 20,
      german: 'Gift versprühen',
      english: 'poisonSpray',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid', 'Sorcerer', 'Warlock', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Constitution',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd12', damageType: 'poison' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du streckst deine Hand in Richtung einer Kreatur in Reichweite, die du sehen kannst, und erzeugst eine Wolke aus ekelhaftem Gas aus deiner Handfläche. Die Kreatur muss einen Rettungswurf auf Konstitution schaffen, sonst erleidet sie 1W12 Giftschaden.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W12 wenn du Stufe 5 (auf 2W12), Stufe 11 (auf 3W12) und Stufe 17 (auf 4W12) erreichst.</p>
      `,
      description_en: `
        <p>You extend your hand toward a creature you can see within range and project a puff of noxious gas from your palm. The creature must succeed on a Constitution saving throw or take 1d12 poison damage.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d12 when you reach 5th level (2d12), 11th level (3d12), and 17th level (4d12).</p>
      `,
      school: 'Conjuration',
      isRanged: true,
      range: 10,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 21,
      german: 'Grünfeuerklinge',
      english: 'greenFlameBlade',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Sorcerer', 'Warlock', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '0', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
      <p>Als Teil der Aktion, mit der du diesen Zauber wirkst, musst du einen Nahkampfangriff mit einer Waffe gegen eine Kreatur in der Reichweite des Zaubers ausführen, sonst misslingt der Zauber. Bei einem Treffer erleidet das Ziel die normalen Auswirkungen des Angriffs, und grünes Feuer springt vom Ziel auf eine andere Kreatur deiner Wahl, die du sehen kannst und die sich innerhalb von 5 Fußn zum Ziel befindet. Die zweite Kreatur erleidet Feuerschaden gleich dem Modifikator deines Attributs zum Zauberwirken.</p>
      <p><b>Auf höheren Stufen:</b> Auf der 5. Stufe fügt der Nahkampfangriff dem Ziel zusätzlich 1W8 Punkte Feuerschaden zu, und der Schaden, den das zweite Ziel erleidet, steigt um 1W8 + der Modifikator deines Attributs zum Zauberwirken. Beide Schadensarten steigen in der 11. und 17. Stufe um 1W8.</p>
      `,
      description_en: `
      <p>As part of the action used to cast this spell, you must make a melee attack with a weapon against one creature within the spell’s range, otherwise the spell fails. On a hit, the target suffers the weapon attack’s normal effects, and green fire leaps from the target to a different creature of your choice that you can see within 5 feet of it. The second creature takes fire damage equal to your spellcasting ability modifier.</p>
      <p><b>At higher levels:</b> At 5th level, the melee attack deals an extra 1d8 fire damage to the target, and the fire damage to the second creature increases to 1d8 + your spellcasting ability modifier. Both damage rolls increase by 1d8 at 11th level and 17th level.</p>
      `,
      school: 'Evocation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 22,
      german: 'Heilige Flamme',
      english: 'sacredFlame',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Cleric'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Dexterity',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd8', damageType: 'radiant' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
      <p>Flammengleiches Licht senkt sich auf eine Kreatur in Reichweite, die du sehen kannst, herab. Die Kreatur muss einen Rettungswurf auf Geschicklichkeit schaffen, sonst erleidet sie 1W8 gleißenden Schaden. Bei einem Rettungswurf erhält das Ziel keinen Vorteil aus Deckung.</p>
      <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W8 wenn du Stufe 5 (auf 2W8), Stufe 11 (auf 3W8) und Stufe 17 (auf 4W8) erreichst.</p>
      `,
      description_en: `
      <p>Flame-like radiance descends on a creature that you can see within range. The target must succeed on a Dexterity saving throw or take 1d8 radiant damage. The target gains no benefit from cover for this saving throw.</p>
      <p><b>At higher levels:</b> The spell’s damage increases by 1d8 when you reach 5th level (2d8), 11th level (3d8), and 17th level (4d8).</p>
      `,
      school: 'Evocation',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 23,
      german: 'Kalte Hand',
      english: 'chillTouch',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Sorcerer', 'Warlock', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd8', damageType: 'necrotic' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
      <p>Du erschaffst eine gespenstische, skelettierte Hand im Bereich einer Kreatur in Reichweite. Mache einen Fernkampf-Zauberangriff gegen die Kreatur, um sie mit der Kälte des Grabes zu attackieren. Bei einem Treffer erleidet die Kreatur 1W8 nekrotischen Schaden und kann bis zu Beginn deines nächsten Zuges keine Trefferpunkt zurückbekommen. Bis dann hält sich die Hand an dem Ziel fest.</p>
      <p>Wenn du eine untote Kreatur triffst, hat sie außerdem Nachteil auf Angriffswürfe gegen dich bis zum Ende deines nächsten Zuges.</p>
      <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W8 wenn du Stufe 5 (auf 2W8), Stufe 11 (auf 3W8) und Stufe 17 (auf 4W8) erreichst.</p>
      `,
      description_en: `
      <p>You create a ghostly, skeletal hand in the space of a creature within range. Make a ranged spell attack against the creature to assail it with the chill of the grave. On a hit, the target takes 1d8 necrotic damage, and it can’t regain hit points until the start of your next turn. Until then, the hand clings to the target.</p>
      <p>If you hit an undead target, it also has disadvantage on attack rolls against you until the end of your next turn.</p>
      <p><b>At higher levels:</b> The spell’s damage increases by 1d8 when you reach 5th level (2d8), 11th level (3d8), and 17th level (4d8).</p>
      `,
      school: 'Necromancy',
      isRanged: true,
      range: 120,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 24,
      german: 'Klingenbann',
      english: 'bladeWard',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Sorcerer', 'Warlock', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 100,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
      <p>Du streckst die Hand aus und zeichnest ein Zeichen des Schutzes in die Luft. Bis zum Ende deines nächsten Zuges hast du Resistenz gegen Wucht-, Hieb- und Stichschaden, der von Angriffen mit Waffen verursacht wird.</p>
      `,
      description_en: `
      <p>You extend your hand and trace a sigil of warding in the air. Until the end of your next turn, you have resistance against bludgeoning, piercing, and slashing damage dealt by weapon attacks.</p>
      `,
      school: 'Abjuration',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 25,
      german: 'Kältestrahl',
      english: 'rayOfFrost',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Sorcerer', 'Wizard', 'Artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd8', damageType: 'cold' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
      <p>Ein eisiger Strahl aus blau-weißem Licht schießt auf eine Kreatur in Reichweite zu. Lege einen Fernkampf-Zauberangriff gegen das Ziel ab. Bei einem Treffer erleidet die Kreatur 1W8 Kälteschaden und ihre Bewegungsrate wird bis zum Beginn deines nächsten Zuges um 10 Fuß verringert.</p>
      <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W8 wenn du Stufe 5 (auf 2W8), Stufe 11 (auf 3W8) und Stufe 17 (auf 4W8) erreichst.</p>
      `,
      description_en: `
      <p>A frigid beam of blue-white light streaks toward a creature within range. Make a ranged spell attack against the target. On a hit, it takes 1d8 cold damage, and its speed is reduced by 10 feet until the start of your next turn.</p>
      <p><b>At higher levels:</b> The spell’s damage increases by 1d8 when you reach 5th level (2d8), 11th level (3d8), and 17th level (4d8).</p>
      `,
      school: 'Evocation',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 26,
      german: 'Lagerfeuer erschaffen',
      english: 'createBonfire',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid', 'Sorcerer', 'Warlock', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 10,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Dexterity',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd8', damageType: 'fire' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
      <p>Du erschaffst ein Lagerfeuer in Reichweite auf dem Boden, den du sehen kannst. Bis der Zauber endet, füllt das Lagerfeuer einen Würfel von 5 Fußn. Jede Kreatur, die sich zum Zeitpunkt des Zaubers im Bereich des Feuers befindet, muss einen Rettungswurf auf Geschicklichkeit ablegen oder 1W8 Feuerschaden erleiden. Eine Kreatur muss den Rettungswurf auch machen, wenn sie den Raum des Lagerfeuers zum ersten Mal in einem Zug betritt oder ihren Zug dort beendet.</p>
      <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W8 wenn du Stufe 5 (auf 2W8), Stufe 11 (auf 3W8) und Stufe 17 (auf 4W8) erreichst.</p>
      `,
      description_en: `
      <p>You create a bonfire on ground that you can see within range. Until the spell ends, the magic bonfire fills a 5-foot cube. Any creature in the bonfire’s space when you cast the spell must succeed on a Dexterity saving throw or take 1d8 fire damage. A creature must also make the saving throw when it enters the bonfire’s space for the first time on a turn or ends its turn there.</p>
      <p><b>At higher levels:</b> The spell’s damage increases by 1d8 when you reach 5th level (2d8), 11th level (3d8), and 17th level (4d8).</p>
      `,
      school: 'Conjuration',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: true,
      areaOfEffectType: 'cube',
      radius: 5,
    },
    {
      id: 27,
      german: 'Licht',
      english: 'light',
      level: 0,
      isCustom: false,
      classes: [
        'Test',
        'Bard',
        'Cleric',
        'Druid',
        'Paladin',
        'Sorcerer',
        'Wizard',
      ],
      timeToCast: 0,
      cost: 'action',
      duration: 600,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: true,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
      <p>Du berührst einen Gegenstand, der nicht größer als 10 Fuß in einer beliebigen Dimension ist. Bis der Zauber endet, strahlt das Objekt helles Licht in einem Radius von 20 Fußn und schwaches Licht für weitere 20 Fuß aus. Das Licht kann nach Belieben gefärbt werden. Wenn du das Objekt vollständig mit etwas Undurchsichtigem abdeckst, wird das Licht blockiert. Der Zauber endet, wenn du ihn erneut wirkst oder ihn als Aktion abbrichst.</p>
      <p>Wenn du ein Objekt anvisierst, das von einer feindlichen Kreatur gehalten oder getragen wird, muss diese Kreatur einen Rettungswurf auf Geschicklichkeit bestehen, um den Zauber zu vermeiden.</p>
      `,
      description_en: `
      <p>You touch one object that is no larger than 10 feet in any dimension. Until the spell ends, the object sheds bright light in a 20-foot radius and dim light for an additional 20 feet. The light can be colored as you like. Completely covering the object with something opaque blocks the light. The spell ends if you cast it again or dismiss it as an action.</p>
      <p>If you target an object held or worn by a hostile creature, that creature must succeed on a Dexterity saving throw to avoid the spell.</p>
      `,
      school: 'Evocation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 28,
      german: 'Magierhand',
      english: 'mageHand',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Sorcerer', 'Warlock', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 10,
      canRitual: 'true',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
      <p>Eine gespenstische, schwebende Hand erscheint an einem Punkt deiner Wahl in Reichweite. Die Hand bleibt für die Wirkungsdauer bestehen oder bis du sie mit einer Aktion wegschickst. Die Hand verschwindet, wenn sie sich weiter als 30 Fuß von dir entfernt oder du den Zauber noch einmal wirkst.</p>
      <p>Du kannst eine Aktion verwenden, um die Hand zu kontrollieren. Du kannst die Hand verwenden, um Gegenstände zu manipulieren, verschlossene Türen oder Behälter zu öffnen, einen Gegenstand aus einem geöffneten Behälter zu holen oder ihn zu verstauen, oder den Inhalt einer Phiole auszugießen. Du kannst die Hand immer wenn du sie verwendest bis zu 9m weit bewegen.</p>
      <p>Die Hand kann nicht angreifen, keine magischen Gegenstände aktivieren oder mehr als 10 Pfund tragen.</p>
      `,
      description_en: `
      <p>A spectral, floating hand appears at a point you choose within range. The hand lasts for the duration or until you dismiss it as an action. The hand vanishes if it is ever more than 30 feet away from you or if you cast this spell again.</p>
      <p>You can use your action to control the hand. You can use the hand to manipulate an object, open an unlocked door or container, stow or retrieve an item from an open container, or pour the contents out of a vial. You can move the hand up to 30 feet each time you use it.</p>
      <p>The hand can’t attack, activate magic items, or carry more than 10 pounds.</p>
      `,
      school: 'Conjuration',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 29,
      german: 'Magiestein',
      english: 'magicStone',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid', 'Hexenmeister'],
      timeToCast: 0,
      cost: 'bonus',
      duration: 10,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd6', damageType: 'bludgeoning' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
      <p>Du berührst ein bis drei Kieselsteine und belegst sie mit Magie. Du oder eine andere Person kann mit einem der Kieselsteine einen Fernzauberangriff durchführen, indem du ihn wirfst oder mit einer Schleuder schleuderst. Wenn du ihn wirfst, hat er eine Reichweite von 60 Fuß. Wenn jemand anderes mit dem Kieselstein angreift, addiert dieser Angreifer deinen Zaubermodifikator, nicht den des Angreifers, zum Angriffswurf. Bei einem Treffer erleidet das Ziel Wuchtschaden in Höhe von 1W6 + deinem Zaubermodifikator. Treffer oder Fehlschuss, der Zauber endet dann auf dem Stein.</p>
      <p>Wenn du diesen Zauber erneut wirkst, endet der Zauber auf allen Steinen, die noch davon betroffen sind, vorzeitig.</p>
      `,
      description_en: `
      <p>You touch one to three pebbles and imbue them with magic. You or someone else can make a ranged spell attack with one of the pebbles by throwing it or hurling it with a sling. If thrown, it has a range of 60 feet. If someone else attacks with the pebble, that attacker adds your spellcasting ability modifier, not the attacker’s, to the attack roll. On a hit, the target takes bludgeoning damage equal to 1d6 + your spellcasting ability modifier. Hit or miss, the spell then ends on the stone.</p>
      <p>If you cast this spell again, the spell ends on any pebbles still affected by your previous casting.</p>
      `,
      school: 'Transmutation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 30,
      german: 'Resistenz',
      english: 'resistance',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Cleric', 'Druid', 'Artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 10,
      canRitual: 'true',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '0', diceType: '', additionalHeal: 0 },
      description_de: `
      <p>Du berührst eine willige Kreatur. Einmal bevor der Zauber endet, kann das Ziel einen W4 werfen und die gewürfelte Zahl zu einem Rettungswurf seiner Wahl addieren. Es kann den Würfel werfen, bevor oder nachdem es den Rettungswurf gemacht hat. Der Zauber endet dann.</p>
      `,
      description_en: `
      <p>You touch one willing creature. Once before the spell ends, the target can roll a d4 and add the number rolled to one saving throw of its choice. It can roll the die before or after making the saving throw. The spell then ends.</p>
      `,
      school: 'Abjuration',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 31,
      german: 'Schauriger Strahl',
      english: 'eldritchBlast',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Hexenmeister'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd10', damageType: 'force' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Ein Strahl aus knisternder Energie schießt auf eine Kreatur in Reichweite zu. Lege einen Fernkampf-Zauberangriff gegen das Ziel ab. Bei einem Treffer erleidet das Ziel 1W10 Energieschaden.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W10 wenn du Stufe 5 (auf 2W10), Stufe 11 (auf 3W10) und Stufe 17 (auf 4W10) erreichst.</p>
      `,
      description_en: `
        <p>A beam of crackling energy streaks toward a creature within range. Make a ranged spell attack against the target. On a hit, the target takes 1d10 force damage.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d10 when you reach 5th level (2d10), 11th level (3d10), and 17th level (4d10).</p>
      `,
      school: 'Evocation',
      isRanged: true,
      range: 120,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 32,
      german: 'Schockgriff',
      english: 'shockingGrasp',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Sorcerer', 'Wizard', 'Artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd8', damageType: 'lightning' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Blitze springen aus deinen Händen und verpassen einer Kreatur, die du zu berühren versuchst, einen Schock. Führe einen Nahkampf-Zauberangriff gegen das Ziel durch. Du hast einen Vorteil beim Angriffswurf, wenn das Ziel Rüstung trägt, die aus Metall besteht. Bei einem Treffer erleidet die Kreatur 1W8 Blitzschaden und kann bis zum Beginn deines nächsten Zuges keine Reaktion durchführen.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W8 wenn du Stufe 5 (auf 2W8), Stufe 11 (auf 3W8) und Stufe 17 (auf 4W8) erreichst.</p>
      `,
      description_en: `
        <p>Lightning springs from your hand to deliver a shock to a creature you try to touch. Make a melee spell attack against the target. You have advantage on the attack roll if the target is wearing armor made of metal. On a hit, the target takes 1d8 lightning damage, and it can’t take reactions until the start of its next turn.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d8 when you reach 5th level (2d8), 11th level (3d8), and 17th level (4d8).</p>
      `,
      school: 'Evocation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 33,
      german: 'Schwertexplosion',
      english: 'swordBurst',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Sorcerer', 'Warlock', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Dexterity',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd6', damageType: 'force' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Für einen Moment fegt eine Schar spektraler Klingen in Kreisform um dich herum. Alle Kreaturen innerhalb von 5 Fußn müssen einen Rettungswurf auf Geschicklichkeit ausführen, ansonsten erleiden sie 1W6 Energieschaden.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W6 wenn du Stufe 5 (auf 2W6), Stufe 11 (auf 3W6) und Stufe 17 (auf 4W6) erreichst.</p>
      `,
      description_en: `
        <p>You create a momentary circle of spectral blades that sweep around you. Each creature within range, other than you, must succeed on a Dexterity saving throw or take 1d6 force damage.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d6 when you reach 5th level (2d6), 11th level (3d6), and 17th level (4d6).</p>
      `,
      school: 'Conjuration',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: true,
      areaOfEffectType: 'circle',
      radius: 5,
    },
    {
      id: 34,
      german: 'Shillelagh',
      english: 'shillelagh',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid'],
      timeToCast: 0,
      cost: 'bonus',
      duration: 10,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '0', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Das Holz einer Keule oder eines Kampfstabs, die du in der Hand hältst, ist mit der Kraft der Natur durchdrungen. Während dieser Zeit kannst du deine Zauberfähigkeit anstelle von Stärke für die Angriffs- und Schadenswürfe von Nahkampfangriffen mit dieser Waffe verwenden, und der Schadenswürfel der Waffe wird zu einem W8. Die Waffe wird außerdem magisch, falls sie es nicht schon ist. Der Zauber endet, wenn du ihn erneut wirkst oder wenn du die Waffe loslässt.</p>
      `,
      description_en: `
        <p>The wood of a club or quarterstaff you are holding is imbued with nature’s power. For the duration, you can use your spellcasting ability instead of Strength for the attack and damage rolls of melee attacks using that weapon, and the weapon’s damage die becomes a d8. The weapon also becomes magical, if it isn’t already. The spell ends if you cast it again or if you let go of the weapon.</p>
      `,
      school: 'Transmutation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 35,
      german: 'Säurespritzer',
      english: 'acidSplash',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Sorcerer', 'Wizard', 'Artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Dexterity',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd6', damageType: 'acid' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du schleuderst eine Blase aus Säure. Wähle eine Kreatur in Reichweite oder zwei Kreaturen in Reichweite, die sich innerhalb von 5 Fuß voneinander befinden. Das Ziel muss einen Rettungswurf auf Geschicklichkeit bestehen oder erleidet 1W6 Säureschaden.</p>
        <p><b>Auf höheren Stufen:</b> Der Schaden des Zaubers erhöht sich um je 1W6 wenn du Stufe 5 (auf 2W6), Stufe 11 (auf 3W6) und Stufe 17 (auf 4W6) erreichst.</p>
      `,
      description_en: `
        <p>You hurl a bubble of acid. Choose one creature within range, or choose two creatures within range that are within 5 feet of each other. A target must succeed on a Dexterity saving throw or take 1d6 acid damage.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d6 when you reach 5th level (2d6), 11th level (3d6), and 17th level (4d6).</p>
      `,
      school: 'Conjuration',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: true,
      areaOfEffectType: 'circle',
      radius: 5,
    },
    {
      id: 36,
      german: 'Tanzende Lichter',
      english: 'dancingLights',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Sorcerer', 'Wizard', 'Artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 10,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '0', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '0', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du erschaffst bis zu vier fackelgroße Lichter in Reichweite, die als Fackeln, Laternen oder leuchtende Kugeln erscheinen, die für die Dauer der Aktion in der Luft schweben. Du kannst die vier Lichter auch zu einer leuchtenden, vage humanoiden Form von mittlerer Größe kombinieren. Unabhängig davon, welche Form du wählst, verströmt jedes Licht ein schwaches Licht in einem Radius von 10 Fuß. Als Bonusaktion in deinem Zug kannst du die Lichter bis zu 300 Fuß weit an einen neuen Platz in Reichweite bewegen. Ein Licht muss sich in einem Umkreis von 20 Fußn um ein anderes durch diesen Zauber erzeugtes Licht befinden, und ein Licht erlischt, wenn es den Wirkungsbereich des Zaubers verlässt.</p>
      `,
      description_en: `
        <p>You create up to four torch-sized lights within range, making them appear as torches, lanterns, or glowing orbs that hover in the air for the duration. You can also combine the four lights into one glowing vaguely humanoid form of Medium size. Whichever form you choose, each light sheds dim light in a 10-foot radius.</p>
        <p>As a bonus action on your turn, you can move the lights up to 60 feet to a new spot within range. A light must be within 20 feet of another light created by this spell, and a light winks out if it exceeds the spell’s range.</p>
      `,
      school: 'Evocation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 37,
      german: 'Taschenspielerei',
      english: 'prestidigitation',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Sorcerer', 'Wizard', 'Artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 600,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '0', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '0', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Dies ist ein einfacher Zaubertrick, den Zauberlehrlinge zum Üben verwenden. Du erzeugst einen der folgenden magischen Effekte in Reichweite:</p>
        <ul>
          <li>Du erzeugst einen unmittelbaren, harmlosen sensorischen Effekt, etwa einen Funkenregen, einen Windstoß, eine leise Melodie oder einen merkwürdigen Geruch.</li>
          <li>Du entzündest oder löschst unmittelbar eine Kerze, eine Fackel oder ein kleines Lagerfeuer.</li>
          <li>Du kannst unmittelbar einen Gegenstand, der nicht größer als ein Würfel mit 1 Fuß Kantenlänge ist, säubern oder verschmutzen.</li>
          <li>Du kannst nichtlebendes Material, das nicht größer als ein Würfel mit 1 Fußn Kantenlänge ist, abkühlen, erhitzen oder würzen. Dies hält eine Stunde lang an.</li>
          <li>Du lässt einen Farbfleck, ein Mal oder ein Symbol eine Stunde lang auf einem Gegenstand oder einer Oberfläche erscheinen.</li>
          <li>Du erzeugst ein nichtmagisches Schmuckstück oder ein illusorisches Bild, das in deine Hand passt und das bis zum Ende deines nächsten Zuges erhalten bleibt.</li>
        </ul>
        <p>Wirkst du diesen Zauber mehrmals, können bis zu drei der langfristigen Effekte gleichzeitig aktiv sein. Du kannst einen solchen Effekt als Aktion beenden.</p>
      `,
      description_en: `
        <p>This spell is a minor magical trick that novice spellcasters use for practice. You create one of the following magical effects within range:</p>
        <ul>
          <li>You create an instantaneous, harmless sensory effect, such as a shower of sparks, a puff of wind, faint musical notes, or an odd odor.</li>
          <li>You instantaneously light or snuff out a candle, a torch, or a small campfire.</li>
          <li>You instantaneously clean or soil an object no larger than 1 cubic foot.</li>
          <li>You chill, warm, or flavor up to 1 cubic foot of nonliving material for 1 hour.</li>
          <li>You make a color, a small mark, or a symbol appear on an object or a surface for 1 hour.</li>
          <li>You create a nonmagical trinket or an illusory image that can fit in your hand and that lasts until the end of your next turn.</li>
        </ul>
        <p>If you cast this spell multiple times, you can have up to three of its non-instantaneous effects active at a time, and you can dismiss such an effect as an action.</p>
      `,
      school: 'Transmutation',
      isRanged: true,
      range: 10,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 38,
      german: 'Verschonung der Toten',
      english: 'spareTheDying',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Cleric'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '0', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du berührst eine lebende Kreatur mit 0 Trefferpunkten. Die Kreatur wird stabilisiert. Der Zauber hat keine Auswirkungen auf Untote oder Konstrukte.</p>
      `,
      description_en: `
        <p>You touch a living creature that has 0 hit points. The creature becomes stable. This spell has no effect on undead or constructs.</p>
      `,
      school: 'Necromancy',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 39,
      german: 'Urtümliche Wildheit',
      english: 'primalSavagery',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd10', damageType: 'acid' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Deine Zähne oder Fingernägel werden zu scharfen Klauen, die du als Nahkampfwaffe verwenden kannst. Du führst einen Nahkampf-Zauberangriff gegen eine Kreatur deiner Wahl durch. Bei einem Treffer erleidet die Kreatur 1W10 Säureschaden.</p>
        <p><b>Auf höheren Graden:</b> Der Schaden des Zaubers erhöht sich um je 1W10 wenn du Stufe 5 (auf 2W10), Stufe 11 (auf 3W10) und Stufe 17 (auf 4W10) erreichst.</p>
      `,
      description_en: `
        <p>You channel primal magic to cause your teeth or fingernails to sharpen, ready to deliver a corrosive attack. Make a melee spell attack against one creature within 5 feet of you. On a hit, the target takes 1d10 acid damage.</p>
        <p><b>At higher levels:</b> The spell’s damage increases by 1d10 when you reach 5th level (2d10), 11th level (3d10), and 17th level (4d10).</p>
      `,
      school: 'Transmutation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 40,
      german: 'Wasser formen',
      english: 'shapeWater',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid', 'Sorcerer', 'Wizard', 'Artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 600,
      canRitual: 'false',
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '0', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '0', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du wählst eine Wasserfläche, die du in Reichweite sehen kannst und die in einen Würfel von 5 Fußn passt. Du manipulierst es auf eine der folgenden Arten:</p>
        <ul>
          <li>Du bewegst das Wasser augenblicklich oder änderst es auf andere Weise, wie du es dir vorstellst, bis zu 5 Fuß in jede Richtung. Diese Bewegung hat nicht genug Kraft, um Schaden zu verursachen.</li>
          <li>Du bringst das Wasser dazu, sich zu einfachen Formen zu formen und sich auf deine Anweisung hin zu bewegen. Diese Veränderung hält 1 Stunde lang an.</li>
          <li>Du veränderst die Farbe oder Deckkraft des Wassers. Das Wasser muss immer auf dieselbe Weise verändert werden. Diese Veränderung hält 1 Stunde lang an.</li>
          <li>Du frierst das Wasser ein, vorausgesetzt, es befinden sich keine Lebewesen darin. Das Wasser taut in 1 Stunde wieder auf.</li>
        </ul>
        <p>Wenn du diesen Zauber mehrmals wirkst, kannst du nicht mehr als zwei seiner nicht sofortigen Effekte gleichzeitig aktiv haben, und du kannst einen solchen Effekt als Aktion abbrechen.</p>
      `,
      description_en: `
      <p>You choose an area of water that you can see within range and that fits within a 5-foot cube. You manipulate it in one of the following ways:</p>
      <ul>
        <li>You instantaneously move or otherwise change the flow of the water as you direct, up to 5 feet in any direction. This movement doesn’t have enough force to cause damage.</li>
        <li>You cause the water to form into simple shapes and animate at your direction. This change lasts for 1 hour.</li>
        <li>You change the water’s color or opacity. The water must be changed in the same way throughout. This change lasts for 1 hour.</li>
        <li>You freeze the water, provided that there are no creatures in it. The water unfreezes in 1 hour.</li>
      </ul>
      <p>If you cast this spell multiple times, you can have no more than two of its non-instantaneous effects active at a time, and you can dismiss such an effect as an action.</p>
      `,
      school: 'Transmutation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: true,
      areaOfEffectType: 'cube',
      radius: 5,
    },
    {
      id: 41,
      german: 'Windböe',
      english: 'gust',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Druid', 'Sorcerer', 'Wizard', 'Artificer'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Strength',
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '0', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du ergreifst die Luft und zwingst sie, einen der folgenden Effekte an einem Punkt in Reichweite, den du sehen kannst, zu erzeugen:</p>
        <ul>
          <li>Eine Kreatur mittlerer oder kleiner Größe, die du auswählst, muss einen Rettungswurf auf Stärke bestehen oder wird bis zu 5 Fuß von dir weggestoßen.</li>
          <li>Du erzeugst einen kleinen Luftstoß, der einen Gegenstand bewegen kann, der weder gehalten noch getragen wird und nicht mehr als 5 Pfund wiegt. Der Gegenstand wird bis zu 10 Fuß von dir weggeschoben. Er wird nicht mit so viel Kraft gestoßen, dass er Schaden anrichtet.</li>
          <li>Du erzeugst mit Luft einen harmlosen sensorischen Effekt, z.B. das Rascheln von Blättern, das Zuschlagen von Fensterläden durch den Wind oder das Kräuseln deiner Kleidung in einer Brise.</li>
        </ul>
      `,
      description_en: `
      <p>You seize the air and compel it to create one of the following effects at a point you can see within range:</p>
      <ul>
        <li>One Medium or smaller creature that you choose must succeed on a Strength saving throw or be pushed up to 5 feet away from you.</li>
        <li>You create a small blast of air capable of moving one object that is neither held nor carried and that weighs no more than 5 pounds. The object is pushed up to 10 feet away from you. It isn’t pushed with enough force to cause damage.</li>
        <li>You create a harmless sensory effect using air, such as causing leaves to rustle, wind to slam shutters shut, or your clothing to ripple in a breeze.</li>
      </ul>
      `,
      school: 'Transmutation',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 42,
      german: 'Wort des Strahlens',
      english: 'wordOfRadiance',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Cleric'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: true,
      savingThrowAttribute: 'Constitution',
      doesDamage: true,
      damage: [{ diceNumber: '1', diceType: 'd6', damageType: 'radiant' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de: `
      <p>Du sprichst ein göttliches Wort aus, und ein brennendes Gleißen bricht aus dir heraus. Jede Kreatur deiner Wahl, welche du innerhalb der Reichweite sehen kannst, muss einen Konstitutionsrettungswurf ablegen oder erleidet 1W6 gleißenden Schaden.</p>
      <p><b>Auf höheren Graden:</b> Der Schaden des Zaubers erhöht sich um je 1W6 wenn du Stufe 5 (auf 2W6), Stufe 11 (auf 3W6) und Stufe 17 (auf 4W6) erreichst.</p>
      `,
      description_en: `
      <p>You utter a divine word, and burning radiance erupts from you. Each creature of your choice that you can see within range must succeed on a Constitution saving throw or take 1d6 radiant damage.</p>
      <p><b>At higher levels:</b> The spell’s damage increases by 1d6 when you reach 5th level (2d6), 11th level (3d6), and 17th level (4d6).</p>
      `,
      school: 'Evocation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: true,
      areaOfEffectType: 'circle',
      radius: 5,
    },
    {
      id: 43,
      german: 'Zielsicherer Schlag',
      english: 'trueStrike',
      level: 0,
      isCustom: false,
      classes: ['Test', 'Sorcerer', 'Wizard'],
      timeToCast: 0,
      cost: 'action',
      duration: 0,
      canRitual: 'false',
      needsVerbal: false,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '0', diceType: '', additionalHeal: 0 },
      description_de: `
        <p>Du streckst deine Hand aus und deutest mit einem Finger auf das Ziel. Deine Magie gewährt dir einen kurzen Einblick in die Verteidigung des Ziels. In deinem nächsten Zug erhältst du Vorteil bei deinem ersten Angriffswurf gegen das Ziel, vorausgesetzt der Zauber ist nicht vorbei.</p>
      `,
      description_en: `
        <p>You extend your hand and point a finger at a target in range. Your magic grants you a brief insight into the target’s defenses. On your next turn, you gain advantage on your first attack roll against the target, provided that this spell hasn’t ended.</p>
      `,
      school: 'Divination',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    // Level 1
    {
      id: 1000,
      german: 'Wunden verursachen',
      english: 'inflictWounds',
      level: 1,
      cost: 'action',
      isCustom: false,
      classes: ['Test', 'Cleric'],
      duration: 0,
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '3', diceType: 'd10', damageType: 'necrotic' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Mach einen Nahkampf-Zauberangriff gegen eine Kreatur deiner Wahl. Bei einem Erfolg erleidet das Ziel 3W10 Nekrotischen Schaden. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, steigt der Schaden für jeden Grad über dem 1. um 1W10.',
      school: 'Necromancy',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1001,
      german: 'Heilende Berührung',
      english: 'cureWounds',
      level: 1,
      cost: 'action',
      duration: 0,
      isCustom: false,
      classes: ['Test', 'Bard', 'Cleric', 'Druid', 'Paladin', 'Ranger'],
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: true,
      heal: { diceNumber: '1', diceType: 'd8', additionalHeal: 4 },
      description_de:
        'Eine Kreatur, die du berührst, gewinnt Trefferpunkte in Höhe von 1W8 + deinem Attributsmodifikator im Zauberwirken zurück. Dieser Zauber wirkt nicht auf Untote oder Konstrukte. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, steigt die Heilung für jeden Grad über dem 1. um 1W8.',
      school: 'Evocation',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1002,
      german: 'Magie entdecken',
      english: 'detectMagic',
      level: 1,
      cost: 'action',
      duration: 100,
      isCustom: false,
      classes: [
        'Test',
        'Bard',
        'Cleric',
        'Druid',
        'Paladin',
        'Ranger',
        'Sorcerer',
        'Wizard',
      ],
      timeToCast: 0,
      canRitual: 'true',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Während der Wirkungsdauer nimmst du die Gegenwart von Magie im Abstand von bis zu 30 Fuß von dir wahr. Wenn du auf diese Weise Magie wahrnimmst, kannst du deine Aktion verwenden, um schwache Auren um sichtbare magische Kreaturen oder Objekte sowie ihre magische Schule zu erkennen, falls vorhanden. Dieser Zauber durchdringt die meisten Barrieren, wird aber von 30 Zentimeter Stein, 2,5 Zentimetern gewöhnlichem Metall, dünnem Bleiblech sowie von einem Meter Holz oder Erde blockiert.',
      school: 'Divination',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1003,
      german: 'Segnen',
      english: 'bless',
      level: 1,
      cost: 'action',
      duration: 10,
      isCustom: false,
      classes: ['Test', 'Cleric', 'Paladin'],
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du segnest bis zu drei Kreaturen deiner Wahl in Reichweite. Wenn ein Ziel während der Wirkungsdauer einen Angriffs- oder Rettungswurf ausführt, darf es mit einem W4 würfeln und das Würfelergebnis zu seinem Angriffs- oder Rettungswurf addieren. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, kannst du für jeden Grad über dem 1. eine zusätzliche Kreatur als Ziel wählen.',
      school: 'Enchantment',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1004,
      german: 'Heilendes Wort',
      english: 'healingWord',
      isCustom: false,
      classes: ['Test', 'Bard', 'Cleric', 'Druid'],
      level: 1,
      cost: 'bonus action',
      duration: 0,
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: false,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: true,
      heal: { diceNumber: '1', diceType: 'd4', additionalHeal: 4 },
      description_de:
        'Eine Kreatur deiner Wahl in Reichweite, die du sehen kannst, gewinnt Trefferpunkte in Höhe von 1W4 + deinem Zauberwirken-Attributsmodifikator zurück. Dieser Zauber wirkt nicht auf Untote oder Konstrukte. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, steigt die Heilung für jeden Grad über dem 1. um 1W4.',
      school: 'Evocation',
      isRanged: true,
      range: 60,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1005,
      german: 'Lenkendes Geschoss',
      english: 'guidingBolt',
      level: 1,
      cost: 'action',
      duration: 0,
      isCustom: false,
      classes: ['Test', 'Cleric'],
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: false,
      needsAttackRoll: true,
      needsSavingThrow: false,
      doesDamage: true,
      damage: [{ diceNumber: '4', diceType: 'd6', damageType: 'radiant' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Ein Lichtblitz schießt auf eine Kreatur deiner Wahl in Reichweite zu. Führe einen Fernkampf-Zauberangriff gegen das Ziel aus. Bei einem Erfolg erleidet das Ziel 4W6 gleißenden Schaden. Dank des mystischen dämmrigen Lichts, das auf dem Ziel glitzert, ist der nächste Angriffswurf gegen das Ziel vor Ende deines nächsten Zugs im Vorteil. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, steigt der Schaden für jeden Grad über dem 1. um 1W6.',
      school: 'Evocation',
      isRanged: true,
      range: 120,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1006,
      german: 'Gift und Krankheiten entdecken',
      english: 'detectPoisonAndDisease',
      level: 1,
      cost: 'action',
      duration: 100,
      isCustom: false,
      classes: ['Test', 'Cleric', 'Druid', 'Paladin', 'Ranger'],
      timeToCast: 0,
      canRitual: 'true',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Während der Wirkungsdauer nimmst du die Gegenwart und die Position von Giften, giftigen Kreaturen und Krankheiten im Abstand von bis zu neun Metern von dir wahr. Du kannst auch die Art des Gifts, der giftigen Kreatur oder der Krankheit bestimmen. Dieser Zauber durchdringt die meisten Barrieren, wird aber von 1 Fußn Stein, 2,5 Zentimetern gewöhnlichem Metall, dünnem Bleiblech sowie von einem Meter Holz oder Erde blockiert.',
      school: 'Divination',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1007,
      german: 'Heldenmut',
      english: 'heroism',
      level: 1,
      cost: 'action',
      duration: 10,
      isCustom: false,
      classes: ['Test', 'Bard', 'Paladin'],
      timeToCast: 0,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: false,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du berührst eine bereitwillige Kreatur und erfüllst sie mit Tapferkeit. Bis der Zauber endet, kann die Kreatur nicht verängstigt werden, und sie erhält zu Beginn jedes ihrer Züge temporäre Trefferpunkte in Höhe deines Zauberwirken-Attributsmodifikators. Wenn der Zauber endet, verliert das Ziel alle verbleibenden temporären Trefferpunkte dieses Zaubers. Auf höheren Graden: Wirkst du diesen Zauber, indem du einen Zauberplatz des 2. Grades oder höher nutzt, kannst du für jeden Grad über dem 1. eine zusätzliche Kreatur als Ziel wählen.',
      school: 'Enchantment',
      isRanged: false,
      range: 5,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1008,
      german: 'Heiligtum',
      english: 'sanctuary',
      level: 1,
      isCustom: false,
      classes: ['Test', 'Cleric'],
      timeToCast: 0,
      cost: 'bonus action',
      duration: 10,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du schützt eine Kreatur in Reichweite vor Angriffen. Während der Wirkungsdauer muss jede Kreatur, die bei einem Angriff oder schädlichen Zauber die geschützte Kreatur als Ziel hat, zuerst einen Weisheitsrettungswurf bestehen. Scheitert der Wurf, muss die Kreatur ein neues Ziel wählen, oder sie verliert den Angriff oder Zauber. Dieser Zauber schützt die entsprechende Kreatur nicht vor Flächeneffekten wie der Explosion eines Feuerballs. Greift die geschützte Kreatur an oder wirkt sie einen Zauber auf eine feindliche Kreatur, endet der Effekt dieses Zaubers.',
      school: 'Abjuration',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },
    {
      id: 1009,
      german: 'Illusion',
      english: 'illusion',
      level: 1,
      isCustom: false,
      classes: ['Test', 'Cleric'],
      timeToCast: 0,
      cost: 'bonus action',
      duration: 10,
      canRitual: 'false',
      needsVerbal: true,
      needsSomatic: true,
      needsMaterial: true,
      needsConcentration: true,
      needsAttackRoll: false,
      needsSavingThrow: false,
      doesDamage: false,
      damage: [{ diceNumber: '', diceType: '', damageType: '' }],
      doesHeal: false,
      heal: { diceNumber: '', diceType: '', additionalHeal: 0 },
      description_de:
        'Du schützt eine Kreatur in Reichweite vor Angriffen. Während der Wirkungsdauer muss jede Kreatur, die bei einem Angriff oder schädlichen Zauber die geschützte Kreatur als Ziel hat, zuerst einen Weisheitsrettungswurf bestehen. Scheitert der Wurf, muss die Kreatur ein neues Ziel wählen, oder sie verliert den Angriff oder Zauber. Dieser Zauber schützt die entsprechende Kreatur nicht vor Flächeneffekten wie der Explosion eines Feuerballs. Greift die geschützte Kreatur an oder wirkt sie einen Zauber auf eine feindliche Kreatur, endet der Effekt dieses Zaubers.',
      school: 'Illusion',
      isRanged: true,
      range: 30,
      hasAreaOfEffect: false,
      areaOfEffectType: '',
      radius: 0,
    },

    // Level 2
  ];
}
